@@ -3,7 +3,6 @@ Module for Terraform Cloud API Endpoint: Audit Trails.
 """
 
 from .endpoint import TFCEndpoint
-from ._constants import MAX_PAGE_SIZE
 
 class TFCAuditTrails(TFCEndpoint):
     """
@@ -31,11 +30,8 @@ class TFCAuditTrails(TFCEndpoint):
         `Audit Trails List API Doc Reference \
             <https://www.terraform.io/docs/cloud/api/audit-trails.html#list-audit-trails>`_
 
-        Query Parameter(s) (`details \
-            <https://www.terraform.io/docs/cloud/api/audit-trails.html#query-parameters>`_):
-            - ``since`` (Optional)
-            - ``page_size`` (Optional)
-            - ``page`` (Optional)
+        `Query Parameter(s) Details \
+            <https://www.terraform.io/docs/cloud/api/audit-trails.html#query-parameters>`__
         """
 
         return self._list(self._audit_trail_api_v2_base_url, \
@@ -48,19 +44,6 @@ class TFCAuditTrails(TFCEndpoint):
         every page so users do not have to implement the paging logic every time they just
         want to list every audit trail in an organization.
 
-        Returns an array of objects.
+        Returns an object with two arrays of objects.
         """
-        current_page_number = 1
-        audit_trails_resp = \
-            self.list(page=current_page_number, page_size=MAX_PAGE_SIZE)
-        total_pages = audit_trails_resp["pagination"]["total_pages"]
-
-        audit_trails = []
-        while current_page_number <= total_pages:
-            audit_trails_resp = \
-                self._list(self._audit_trail_api_v2_base_url, \
-                    page=current_page_number, page_size=MAX_PAGE_SIZE)
-            audit_trails += audit_trails_resp["data"]
-            current_page_number += 1
-
-        return audit_trails
+        return self._list_all(self._audit_trail_api_v2_base_url)
