@@ -19,6 +19,12 @@ class TFCPlans(TFCEndpoint):
     def required_entitlements(self):
         return [Entitlements.OPERATIONS]
 
+    def terraform_cloud_only(self):
+        return False
+
+    def terraform_enterprise_only(self):
+        return False
+
     def show(self, plan_id):
         """
         ``GET /plans/:id``
@@ -39,7 +45,6 @@ class TFCPlans(TFCEndpoint):
         """
         if plan_id is not None:
             url = f"{self._endpoint_base_url}/{plan_id}/json-output"
-            self._logger.error(f"This endpoint ({url}) does not yet work.")
         elif run_id is not None:
             url = f"{self._runs_base_url}/{run_id}/plan/json-output"
         else:
