@@ -25,7 +25,7 @@ class TFCRuns(TFCEndpoint):
     def terraform_enterprise_only(self):
         return False
 
-    def list(self, workspace_id, page=None, page_size=None, include=None):
+    def list(self, workspace_id, page=None, page_size=None, include=None, search=None, filters=None):
         """
         ``GET /workspaces/:workspace_id/runs``
 
@@ -37,9 +37,9 @@ class TFCRuns(TFCEndpoint):
         """
 
         url = f"{self._ws_api_v2_base_url}/{workspace_id}/runs"
-        return self._list(url, page=page, page_size=page_size, include=include)
+        return self._list(url, page=page, page_size=page_size, include=include, search=search, filters=filters)
 
-    def list_all(self, workspace_id, include=None):
+    def list_all(self, workspace_id, include=None, search=None, filters=None):
         """
         This function does not correlate to an endpoint in the TFC API Docs specifically,
         but rather is a helper function to wrap the `list` endpoint, which enumerates out
@@ -49,7 +49,7 @@ class TFCRuns(TFCEndpoint):
         Returns an object with two arrays of objects.
         """
         url = f"{self._ws_api_v2_base_url}/{workspace_id}/runs"
-        return self._list_all(url, include=include)
+        return self._list_all(url, include=include, search=search, filters=filters)
 
     def show(self, run_id, include=None):
         """
