@@ -46,7 +46,7 @@ class TestTFCBaseTestCase(unittest.TestCase):
 
         cls._api = TFC(\
             cls._test_api_token, url=cls._tfc_url, \
-                verify=cls._ssl_verify, log_level=cls._TERRASNEK_LOG_LEVEL)
+                verify=cls._ssl_verify, log_level=cls._TERRASNEK_LOG_LEVEL, skip_version_check=True)
 
         cls._test_username = TEST_USERNAME
         cls._test_email = TEST_EMAIL
@@ -97,8 +97,11 @@ class TestTFCBaseTestCase(unittest.TestCase):
         missing_entitlements = cls._get_missing_entitlements(cls._endpoint_being_tested)
 
         if missing_entitlements:
+            cls._logger.debug(\
+                "Missing required Terraform Cloud Entitlements for test: %s", \
+                    missing_entitlements)
             raise unittest.SkipTest(\
-                "Missing required Terraform Cloud Entitlments for test", \
+                "Missing required Terraform Cloud Entitlements for test", \
                     cls._unittest_name, missing_entitlements)
 
         endpoint_to_test = getattr(cls._api, cls._endpoint_being_tested)
@@ -125,6 +128,7 @@ class TestTFCBaseTestCase(unittest.TestCase):
 
     @classmethod
     def _purge_organization(cls):
+        # TODO: change as many of these to list_all as possible
         cls._logger.info(\
             f"Purging test org ({cls._test_org_name}) of all resources to start fresh...")
 
@@ -164,9 +168,18 @@ class TestTFCBaseTestCase(unittest.TestCase):
             cls._api.ssh_keys.destroy(ssh_key["id"])
         cls._logger.debug(f"SSH keys purged from test org ({cls._test_org_name}).")
 
+        # Deleting all the projects
+        cls._logger.debug(f"Purging test org ({cls._test_org_name}) of projects...")
+        projects = cls._api.projects.list_all()["data"]
+        for project in projects:
+            project_name = project["attributes"]["name"]
+            if project_name != "Default Project":
+                cls._api.projects.destroy(project["id"])
+        cls._logger.debug(f"Projects purged from test org ({cls._test_org_name}).")
+
         # Deleting the teams will delete all team memberships, and team tokens
         cls._logger.debug(f"Purging test org ({cls._test_org_name}) of teams...")
-        teams = cls._api.teams.list()["data"]
+        teams = cls._api.teams.list_all()["data"]
         for team in teams:
             team_name = team["attributes"]["name"]
             if team_name != "owners":
@@ -174,6 +187,21 @@ class TestTFCBaseTestCase(unittest.TestCase):
         cls._logger.debug(f"Teams purged from test org ({cls._test_org_name}).")
 
         cls._logger.debug(f"Purging test org ({cls._test_org_name}) of org membership invites...")
+        org_tags = cls._api.org_tags.list_tags()["data"]
+        if len(org_tags) > 0:
+            delete_tags_payload = {
+                "data": []
+            }
+            for org_tag in org_tags:
+                delete_tags_payload["data"].append({
+                    "type": "tags",
+                    "id": org_tag["id"]
+
+                })
+            cls._api.org_tags.delete_tags(delete_tags_payload)
+        cls._logger.debug(f"Org tags purged from test org ({cls._test_org_name}).")
+
+        cls._logger.debug(f"Purging test org ({cls._test_org_name}) of org tags...")
         org_memberships = cls._api.org_memberships.list_all_for_org()["data"]
         for org_membership in org_memberships:
             membership_id = org_membership["id"]
@@ -182,6 +210,7 @@ class TestTFCBaseTestCase(unittest.TestCase):
                 cls._api.org_memberships.remove(membership_id)
         cls._logger.debug(f"Org member invites purged from test org ({cls._test_org_name}).")
 
+
         cls._logger.debug(f"Purging test org ({cls._test_org_name}) of agent pools...")
         agent_pools = cls._api.agents.list_pools()["data"]
         for agent_pool in agent_pools:
@@ -354,18 +383,18 @@ class TestTFCBaseTestCase(unittest.TestCase):
             }
         }
 
-    def _get_ws_with_vcs_create_payload(self, oauth_token_id, working_dir=DEFAULT_VCS_WORKING_DIR):
-        # NB: Needs to be TF > v0.12 for Cost Estimation to work
+    def _get_ws_with_vcs_create_payload(self, oauth_token_id, branch="main", working_dir=DEFAULT_VCS_WORKING_DIR):
+        # NOTE: Needs to be TF > v0.12 for Cost Estimation to work
         return {
             "data": {
                 "attributes": {
                     "name": self._unittest_random_name(),
-                    "terraform_version": "1.0.3",
+                    "terraform_version": "1.3.2",
                     "working-directory": working_dir,
                     "vcs-repo": {
                         "identifier": "dahlke/terrasnek-unittest-config",
                         "oauth-token-id": oauth_token_id,
-                        "branch": "master"
+                        "branch": branch
                     },
                     "global-remote-state": False
                 },
@@ -429,7 +458,7 @@ class TestTFCBaseTestCase(unittest.TestCase):
                     "global": False,
                     "policies-path": "sentinel/",
                     "vcs-repo": {
-                        "branch": "master",
+                        "branch": "main",
                         "identifier": "dahlke/terrasnek-unittest-config",
                         "ingress-submodules": False,
                         "oauth-token-id": oauth_token_id
@@ -478,7 +507,7 @@ class TestTFCBaseTestCase(unittest.TestCase):
             "data": {
                 "type": "organizations",
                 "attributes": {
-                    "name": self._unittest_random_name(),
+                    "name": self._unittest_random_name(ran_str_len=4),
                     "organization-access": {
                         "manage-workspaces": True,
                         "manage-policies": True,
@@ -502,6 +531,16 @@ class TestTFCBaseTestCase(unittest.TestCase):
             }
         }
 
+    def _get_project_create_payload(self):
+        return {
+            "data": {
+                "type": "projects",
+                "attributes": {
+                    "name": self._unittest_random_name(ran_str_len=4)
+                }
+            }
+        }
+
     @timeout_decorator.timeout(MAX_TEST_TIMEOUT)
     def _created_run_timeout(self, run_id):
         """
@@ -509,12 +548,15 @@ class TestTFCBaseTestCase(unittest.TestCase):
         from the API to match the expected output. This function provides some time cushion for
         terraform plans to occur after creating a run.
         """
+        iterations_waited = 0
         created_run = self._api.runs.show(run_id)["data"]
         while not created_run["attributes"]["status"] == "planned_and_finished" and \
-            not created_run["attributes"]["actions"]["is-confirmable"]:
+            not created_run["attributes"]["actions"]["is-confirmable"] and \
+                iterations_waited != 20:
             created_run = self._api.runs.show(run_id)["data"]
             self._logger.debug("Waiting for created run to finish planning...")
             time.sleep(1)
+            iterations_waited += 1
         self._logger.debug("Plan successful.")
         return created_run
 
