@@ -23,7 +23,7 @@ class TestTFCConfigVersions(TestTFCBaseTestCase):
         self._oauth_client_id = oauth_client["data"]["id"]
         oauth_token_id = oauth_client["data"]["relationships"]["oauth-tokens"]["data"][0]["id"]
 
-        ws_payload = self._get_ws_with_vcs_create_payload(oauth_token_id)
+        ws_payload = self._get_ws_with_vcs_create_payload(oauth_token_id, working_dir="tfe")
         self._ws_w_vcs = self._api.workspaces.create(ws_payload)
         self._ws_w_vcs_id = self._ws_w_vcs["data"]["id"]
 
@@ -104,9 +104,11 @@ class TestTFCConfigVersions(TestTFCBaseTestCase):
                     self._api.config_versions.download_version_files(run_id=run_id)
                 self.assertIn("redirected", download_config_version_run)
 
+                # Create a second config version so that we can archive the first one
+                self._api.config_versions.create(self._ws_id, self._get_config_version_create_payload())
                 self._api.config_versions.archive_version(cv_id)
                 config_versions = self._api.config_versions.list(self._ws_id)["data"]
-                self.assertEqual(config_versions[0]["attributes"]["status"], "archived")
+                self.assertEqual(config_versions[-1]["attributes"]["status"], "archived")
 
     def test_config_versions_includes(self):
         """
