@@ -3,6 +3,7 @@ Module for testing the Terraform Cloud API Endpoint: Policy Sets.
 """
 
 import time
+
 from .base import TestTFCBaseTestCase
 from ._constants import PAGE_START, PAGE_SIZE
 
@@ -52,12 +53,17 @@ class TestTFCPolicySets(TestTFCBaseTestCase):
                 "value": "false"
             }
         ]
+
+        search_payload = {
+            "name": created_policy_set_name
+        }
+
         some_policy_sets = self._api.policy_sets.list(\
-            filters=test_filters, page=PAGE_START, page_size=PAGE_SIZE, search=created_policy_set_name)["data"]
+            filters=test_filters, page=PAGE_START, page_size=PAGE_SIZE, search=search_payload)["data"]
         self.assertEqual(len(some_policy_sets), 1)
 
         all_policy_sets = self._api.policy_sets.list_all(\
-            filters=test_filters, search=created_policy_set_name)
+            filters=test_filters, search=search_payload)
         self.assertEqual(len(all_policy_sets["data"]), 1)
 
         # Update the policy set, confirm the update took place
@@ -118,7 +124,7 @@ class TestTFCPolicySets(TestTFCBaseTestCase):
         self.assertEqual(len(shown_policy_set["relationships"]["workspaces"]["data"]), 0)
 
         some_policy_sets_raw = self._api.policy_sets.list(\
-            filters=test_filters, page=PAGE_START, page_size=PAGE_SIZE, search=created_policy_set_name, \
+            filters=test_filters, page=PAGE_START, page_size=PAGE_SIZE, search=search_payload, \
                 include=["policies"])
         self.assertIn("included", some_policy_sets_raw)
 
